package net.sf.itcb.module.blank.business.exception;

import net.sf.itcb.common.business.exceptions.ExceptionMappingErrors;

/**
 * Generic enum example in order to declare all the errors the module can declare<br/>
 * Each module must declare its own exception mapping errors extending {@link net.sf.itcb.common.business.exceptions.ExceptionMappingErrors}.<br/>
 * This class has to respect some rules :
 * 
 * <ul>
 * <li>the key must be prefixed by the module name (ie : <i>BLANK_</i>)</li>
 * <li>the errors code must be over 1000 because generic id are between 0 and 999</li>
 * <li>the message has to be prefixed by the module name (ie : <i>blank.</i>)</li>
 * </ul>
 *
 * The enum will be usefull if the errors types has to be shared in a web-service.
 * 
 * @author Pierre Le Roux
 */
public enum BlankExceptionMappingErrors implements ExceptionMappingErrors{
	
	BLANK_NOT_SET_ID("blank.not_set_id"),
	BLANK_MY_FUNCTIONAL_EXCEPTION_1("blank.exception1"),
	BLANK_MY_FUNCTIONAL_EXCEPTION_2("blank.exception2"),
	BLANK_MY_FUNCTIONAL_EXCEPTION_3("blank.exception3");
	
	private String message;
	
	BlankExceptionMappingErrors(String msg) {
		this.message=msg;
	}

	public String getMessage() {
		return message;
	}
	
	public String getMessageKey() {
		return this.toString();
	}

}
