package net.sf.itcb.module.blank.business.service;

import net.sf.itcb.module.blank.schemas.GetAllBlanksRequest;
import net.sf.itcb.module.blank.schemas.GetAllBlanksResponse;
import net.sf.itcb.module.blank.schemas.GetBlankRequest;
import net.sf.itcb.module.blank.schemas.GetBlankResponse;
import net.sf.itcb.module.blank.schemas.SaveBlankRequest;
import net.sf.itcb.module.blank.schemas.SaveBlankResponse;
import net.sf.itcb.module.blank.schemas.UpdateManyBlanksRequest;
import net.sf.itcb.module.blank.schemas.UpdateManyBlanksResponse;

/**
 * An example service interface.
 * 
 * @author Pierre Le Roux
 */
public interface BlankService {
	
	/**
	 * retrieve a BlankBean by its id
	 * @param id the id
	 * @return the BlankBean associated to the id
	 * @throws Exception technical or functional exceptions
	 */
	public GetBlankResponse getBlankById(GetBlankRequest getBlankRequestType) throws Exception;
	
	/**
	 * save a blankBean
	 * @param blankBean the BlankBean to insert or update
	 * @return the BlankBean updated (with the id populated)
	 * @throws Exception technical or functional exceptions
	 */
	public SaveBlankResponse saveBlank(SaveBlankRequest saveBlankRequest) throws Exception;
	
	/**
	 * update many blanks in one transaction
	 * @param listBlankBean a list of BlankBean to update. Ids must have been set.
	 * @throws Exception technical or functional exceptions
	 */
	public UpdateManyBlanksResponse updateManyBlanks(UpdateManyBlanksRequest updateManyBlanksRequest) throws Exception;
	
	/**
	 * retrieve all blanks
	 * @return the list of all BlankBean
	 * @throws Exception technical or functional exceptions
	 */
	public GetAllBlanksResponse getAllBlanks(GetAllBlanksRequest getAllBlanksRequest) throws Exception;
}
